@@ -4,6 +4,7 @@ import numpy as np
 import math
 import pandas as pd
 import scipy.stats as ss
+import scipy.stats as stats
 import matplotlib.pyplot as plt
 import matplotlib.gridspec as gridspec
 
@@ -26,7 +27,7 @@ class PlotProteinHistogram(PrintColors):
         ----------
         intersection_display_flag: bool
             This flag can be used when we want to see the result of intersection on
-            top of v-shaped (Please read tutorials 4).
+            top of v-shaped (Please read tutorials 3).
 
         imgSizex: int
             The width of the histogram figure.
@@ -73,6 +74,16 @@ class PlotProteinHistogram(PrintColors):
         self.t_iPSFCentroidSigmas_fit_x = []
         self.t_iPSFCentroidSigmas_fit_y = []
 
+        self.t_mean_x_center_bright = []
+        self.t_std_x_center_bright = []
+        self.t_mean_y_center_bright = []
+        self.t_std_y_center_bright = []
+
+        self.t_mean_x_center_dark = []
+        self.t_std_x_center_dark = []
+        self.t_mean_y_center_dark = []
+        self.t_std_y_center_dark = []
+
     def __call__(self, folder_name, particles, batch_size, video_frame_num, MinPeakWidth, MinPeakProminence,
                  pixel_size=0.66):
         """
@@ -147,6 +158,8 @@ class PlotProteinHistogram(PrintColors):
                     fit_X_sigma = None
                     fit_Y_sigma = None
 
+                self.localization(x_center, y_center, center_int)
+
                 self.data_handling(center_int, center_int_flow, folder_name, sigma, num_parameters, fit_intensity,
                                    fit_X_sigma, fit_Y_sigma, frame_number, batch_size, video_frame_num,
                                    MinPeakWidth=MinPeakWidth, MinPeakProminence=MinPeakProminence)
@@ -211,10 +224,24 @@ class PlotProteinHistogram(PrintColors):
                     fit_X_sigma = None
                     fit_Y_sigma = None
 
+                self.localization(x_center, y_center, center_int)
+
                 self.data_handling(center_int, center_int_flow, folder_name, sigma, num_parameters, fit_intensity,
                                    fit_X_sigma, fit_Y_sigma, frame_number, batch_size, video_frame_num,
                                    MinPeakWidth=MinPeakWidth, MinPeakProminence=MinPeakProminence)
 
+    def localization(self, x_center, y_center, center_int):
+        if np.mean(center_int) >= 0:
+            self.t_mean_x_center_bright.append(np.mean(x_center))
+            self.t_std_x_center_bright.append(np.std(x_center))
+            self.t_mean_y_center_bright.append(np.mean(y_center))
+            self.t_std_y_center_bright.append(np.std(y_center))
+        elif np.mean(center_int) < 0:
+            self.t_mean_x_center_dark.append(np.mean(x_center))
+            self.t_std_x_center_dark.append(np.std(x_center))
+            self.t_mean_y_center_dark.append(np.mean(y_center))
+            self.t_std_y_center_dark.append(np.std(y_center))
+
     def data_handling(self, center_int, center_int_flow, folder_name, sigma, num_parameters, fit_intensity,
                       fit_X_sigma, fit_Y_sigma, frame_number, batch_size, video_frame_num, MinPeakWidth, MinPeakProminence):
         if len(center_int) != 0:
@@ -439,7 +466,8 @@ class PlotProteinHistogram(PrintColors):
             mean_ = 0
         return mean_, std_
 
-    def extract_hist_information(self, con_intersections, con_peaks, con_proms, upper_limitation=1, lower_limitation=-1, max_n_components=3, Flag_GMM_fit=True):
+    def extract_hist_information(self, con_intersections, con_peaks, con_proms, upper_limitation=1, lower_limitation=-1,
+                                 max_n_components=3, Flag_GMM_fit=True):
         t_contrast_intersection = np.asarray(con_intersections)
         t_contrast_intersection = t_contrast_intersection[~np.isnan(t_contrast_intersection)]
 
@@ -553,13 +581,17 @@ class PlotProteinHistogram(PrintColors):
         list_weights = []
         list_keys = []
         list_num_GMM = []
+        list_AIC = []
+        list_BIC = []
         if Flag_GMM_fit:
             for data, key in zip(list_data, title):
                 try:
-                    means, stdevs, weights = self.GMM(np.abs(data), max_n_components)
+                    means, stdevs, weights, AIC, BIC = self.GMM(np.abs(data), max_n_components)
                     list_means.append(means)
                     list_stds.append(stdevs)
                     list_weights.append(weights)
+                    list_AIC.append(AIC)
+                    list_BIC.append(BIC)
                     list_keys.append(key)
                     list_num_GMM.append(len(means))
 
@@ -568,10 +600,14 @@ class PlotProteinHistogram(PrintColors):
                     list_means.append(None)
                     list_stds.append(None)
                     list_weights.append(None)
+                    list_AIC.append(None)
+                    list_BIC.append(None)
                     list_keys.append(key)
                     list_num_GMM.append(None)
 
-            max_num_gmm_mean = np.max(list_num_GMM)
+            list_num_GMM_temp = [x for x in list_num_GMM if x is not None]
+            max_num_gmm_mean = np.max(list_num_GMM_temp)
+
             for means, stdevs, weights, key in zip(list_means, list_stds, list_weights, list_keys):
                 if means is not None:
                     if len(means) == max_num_gmm_mean:
@@ -638,7 +674,8 @@ class PlotProteinHistogram(PrintColors):
         BIC = [m.bic(data) for m in models if m is not None]
 
         try:
-            M_best = models[np.nanargmin(AIC)]
+            num_mixture = np.min([np.nanargmin(AIC), np.nanargmin(BIC)])
+            M_best = models[num_mixture]
 
             means = M_best.means_
             stdevs = np.sqrt(M_best.covariances_)
@@ -653,10 +690,10 @@ class PlotProteinHistogram(PrintColors):
             stdevs = [sci_num(s_[0][0]) for s_ in stdevs_]
             weights = [sci_num(w_) for w_ in weights_]
 
-            return means, stdevs, weights
+            return means, stdevs, weights, AIC, BIC
         except:
-            return np.nan, np.nan, np.nan
             print('---Data is not enough for GMM!---')
+            return np.nan, np.nan, np.nan, np.nan, np.nan
 
     def frameNumber_longerProfile_2_Vshape(self, batch_size, video_shape_0, particle_frame_number, V_smooth_follow):
         BS2 = 2 * batch_size
@@ -754,7 +791,7 @@ class PlotProteinHistogram(PrintColors):
 
     def plot_histogram(self, bins=None, upper_limitation=1, lower_limitation=-1,
                        step_range=1e-7, face='g', edge='y', Flag_GMM_fit=True, max_n_components=3, imgSizex=20,
-                       imgSizey=20, font_size=12):
+                       imgSizey=20, font_size=12, scale=1e1, external_GMM=False):
         """
         This method plots histograms for different contrast extraction methods for black PSFs, white PSFs and all together.
 
@@ -793,6 +830,11 @@ class PlotProteinHistogram(PrintColors):
         font_size: float
             The font size of the text in the table information.
 
+        scale: float
+            This value multiplies the full range for x-axis plotting.
+
+        external_GMM: bool
+            This flag modifies GMM's visualization. Only the external border is visible if it is set to True.
         """
 
         df, list_data, title = self.extract_hist_information(con_intersections=self.t_contrast_intersection,
@@ -837,8 +879,14 @@ class PlotProteinHistogram(PrintColors):
                     density = np.sum(np.array(pdfs), axis=0)
                     ax = plt.Subplot(fig, inner[p_index])
                     ax.hist(d_, bins=bins, fc=face, ec=edge, density=True)
-                    ax.axis(xmin=0, xmax=upper_limitation * 1e1)
-                    ax.plot(x.ravel(), density.ravel())
+                    ax.axis(xmin=0, xmax=upper_limitation * scale)
+                    if external_GMM:
+                        ax.plot(x.ravel(), density.ravel())
+                    else:
+                        for j_ in range(len(weights)):
+                            if weights[j_] is not None:
+                                ax.plot(x.ravel(), float(weights[j_]) * stats.norm.pdf(x.ravel(), float(means[j_]), float(stdevs[j_])).ravel())
+
                     ax.set_ylabel('Density')
                     ax.set_title(title[p_index])
                     ax.ticklabel_format(style='sci', axis='x', scilimits=(0, 0))
@@ -849,7 +897,7 @@ class PlotProteinHistogram(PrintColors):
 
                     ax = plt.Subplot(fig, inner[p_index])
                     ax.hist(d_, bins=bins, fc=face, ec=edge, density=False)
-                    ax.axis(xmin=0, xmax=upper_limitation * 1e1)
+                    ax.axis(xmin=0, xmax=upper_limitation * scale)
                     ax.set_ylabel('#Counts')
                     ax.set_title(title[p_index])
                     ax.ticklabel_format(style='sci', axis='x', scilimits=(0, 0))
@@ -860,7 +908,7 @@ class PlotProteinHistogram(PrintColors):
 
                 ax = plt.Subplot(fig, inner[p_index])
                 ax.hist(d_, bins=bins, fc=face, ec=edge, density=False)
-                ax.axis(xmin=0, xmax=upper_limitation * 1e1)
+                ax.axis(xmin=0, xmax=upper_limitation * scale)
                 ax.set_ylabel('#Counts')
                 ax.set_title(title[p_index])
                 ax.ticklabel_format(style='sci', axis='x', scilimits=(0, 0))
@@ -878,46 +926,52 @@ class PlotProteinHistogram(PrintColors):
         plt.show()
 
     def plot_fit_histogram(self, bins=None, upper_limitation=1, lower_limitation=-1, step_range=1e-7, face='g',
-                           edge='y',
-                           Flag_GMM_fit=True, max_n_components=3, imgSizex=20, imgSizey=20, font_size=12):
+                           edge='y', Flag_GMM_fit=True, max_n_components=3, imgSizex=20, imgSizey=20, font_size=12,
+                           scale=1e1, external_GMM=False):
         """
         This method plots histograms for 2D Gaussian fitting contrast for black PSFs, white PSFs and all together.
 
-       Parameters
-       ----------
-       bins: int
+        Parameters
+        ----------
+        bins: int
            Number of histogram bins.
 
-       upper_limitation: float
+        upper_limitation: float
            The upper limit for trimming histogram.
 
-       lower_limitation: float
+        lower_limitation: float
            The lower limit for trimming histogram.
 
-       step_range: float
+        step_range: float
            The resolution that is used for GMM plotting.
 
-       face: str
+        face: str
            Face color of the histogram.
 
-       edge: str
+        edge: str
            Edge color of the histogram.
 
-       Flag_GMM_fit: bool
+        Flag_GMM_fit: bool
            Activate/Deactivate GMM.
 
-       max_n_components: int
+        max_n_components: int
            The maximum number of components that GMM used for AIC and BIC tests. This helps to find an optimum number of the mixture.
 
-       imgSizex: int
+        imgSizex: int
            The width of the histogram figure.
 
-       imgSizey: int
+        imgSizey: int
            The height of the histogram figure.
 
-       font_size: float
+        font_size: float
            The font size of the text in the table information.
 
+        scale: float
+                   This value multiplies the full range for x-axis plotting.
+
+        external_GMM: bool
+           This flag modifies GMM's visualization. Only the external border is visible if it is set to True.
+
         """
 
         df, list_data, title = self.extract_hist_information(con_intersections=self.t_contrast_fit_intersection,
@@ -931,56 +985,71 @@ class PlotProteinHistogram(PrintColors):
         fig = plt.figure(figsize=(imgSizex, imgSizey))
         outer = gridspec.GridSpec(2, 1, wspace=0.3, hspace=0.2)
 
-        inner = gridspec.GridSpecFromSubplotSpec(3, 3, subplot_spec=outer[0], wspace=0.3, hspace=0.7)
+        inner = gridspec.GridSpecFromSubplotSpec(3, 3,
+                                                 subplot_spec=outer[0], wspace=0.3, hspace=0.7)
 
         for p_index in range(len(list_data)):
             if Flag_GMM_fit:
-                key = title[p_index]
-                means = df[key]['GMM_Means']
-                stdevs = df[key]['GMM_Stds']
-                weights = df[key]['GMM_Weights']
-                if means is None or stdevs is None or weights is None:
-                    d_ = np.abs(list_data[p_index])
-                    nan_array = np.isnan(d_)
-                    not_nan_array = ~ nan_array
-                    d_ = d_[not_nan_array]
+                try:
+                    key = title[p_index]
+                    index_ = df.index.to_list()
+                    pdfs = []
+                    means = []
+                    stdevs = []
+                    weights = []
+                    for idx_ in index_:
+                        if 'GMM_mean' in idx_:
+                            means.append(df[key][idx_])
+                        elif 'GMM_std' in idx_:
+                            stdevs.append(df[key][idx_])
+                        elif 'GMM_weight' in idx_:
+                            weights.append(df[key][idx_])
 
-                    min_data = np.nanmin(d_)
-                    max_data = np.nanmax(d_)
+                    d_ = np.abs(list_data[p_index])
+                    min_data = np.min(d_) - 0.5 * np.min(d_)
+                    max_data = np.max(d_) + 0.5 * np.max(d_)
 
                     x = np.arange(min_data, max_data, step_range)
-                    pdfs = [p * ss.norm.pdf(x, mu, sd) for mu, sd, p in zip(means, stdevs, weights)]
+
+                    pdfs = [float(p) * ss.norm.pdf(x, float(mu), float(sd)) for mu, sd, p in zip(means, stdevs, weights)
+                            if mu is not None and sd is not None and p is not None]
                     density = np.sum(np.array(pdfs), axis=0)
                     ax = plt.Subplot(fig, inner[p_index])
                     ax.hist(d_, bins=bins, fc=face, ec=edge, density=True)
-                    ax.plot(x.ravel(), density.ravel())
-                    ax.xlim(lower_limitation, upper_limitation)
+                    ax.axis(xmin=0, xmax=upper_limitation * scale)
+                    if external_GMM:
+                        ax.plot(x.ravel(), density.ravel())
+                    else:
+                        for j_ in range(len(weights)):
+                            if weights[j_] is not None:
+                                ax.plot(x.ravel(), float(weights[j_]) * stats.norm.pdf(x.ravel(), float(means[j_]),
+                                                                                       float(stdevs[j_])).ravel())
+
                     ax.set_ylabel('Density')
                     ax.set_title(title[p_index])
+                    ax.ticklabel_format(style='sci', axis='x', scilimits=(0, 0))
                     fig.add_subplot(ax)
 
-                else:
+                except:
                     d_ = np.abs(list_data[p_index])
-                    nan_array = np.isnan(d_)
-                    not_nan_array = ~ nan_array
-                    d_ = d_[not_nan_array]
 
                     ax = plt.Subplot(fig, inner[p_index])
                     ax.hist(d_, bins=bins, fc=face, ec=edge, density=False)
+                    ax.axis(xmin=0, xmax=upper_limitation * scale)
                     ax.set_ylabel('#Counts')
                     ax.set_title(title[p_index])
+                    ax.ticklabel_format(style='sci', axis='x', scilimits=(0, 0))
                     fig.add_subplot(ax)
 
             else:
-                d_ = list_data[p_index]
-                nan_array = np.isnan(d_)
-                not_nan_array = ~ nan_array
-                d_ = d_[not_nan_array]
+                d_ = np.abs(list_data[p_index])
 
                 ax = plt.Subplot(fig, inner[p_index])
                 ax.hist(d_, bins=bins, fc=face, ec=edge, density=False)
+                ax.axis(xmin=0, xmax=upper_limitation * scale)
                 ax.set_ylabel('#Counts')
                 ax.set_title(title[p_index])
+                ax.ticklabel_format(style='sci', axis='x', scilimits=(0, 0))
                 fig.add_subplot(ax)
 
         ax2 = plt.Subplot(fig, outer[1])
@@ -1011,6 +1080,67 @@ class PlotProteinHistogram(PrintColors):
         plt.title('Ratio mean of Sigma_Max/Sigma_Min=' + str(ratio_sigma))
         plt.show()
 
+    def plot_localization_heatmap(self, pixel_size, unit):
+        """
+        This method generates a particle localization heatmap. Every disk's size represents the movement of each particle during tracking.
+
+        Parameters
+        ----------
+        pixel_size: float
+            camera pixel size
+
+        unit: str
+            unit of axises
+        """
+        bubble_size_bright_ = np.maximum(self.t_std_y_center_bright, self.t_std_x_center_bright)
+        bubble_size_dark_ = np.maximum(self.t_std_y_center_dark, self.t_std_x_center_dark)
+
+        print('Number of dark particles {}'.format(bubble_size_bright_.shape[0]))
+        print('Number of bright particles {}'.format(bubble_size_dark_.shape[0]))
+
+        bubble_size_bright = []
+        for s_b in bubble_size_bright_:
+            if s_b == 0:
+                bubble_size_bright.append(s_b + 1e-6)
+            else:
+                bubble_size_bright.append(s_b)
+
+        bubble_size_dark = []
+        for s_d in bubble_size_dark_:
+
+            if s_d == 0:
+                bubble_size_dark.append(s_d + 1e-6)
+            else:
+                bubble_size_dark.append(s_d)
+
+        dic_dark = {'list_Dark_iPSFx': np.multiply(pixel_size, self.t_mean_x_center_dark),
+                    'list_Dark_iPSFy': np.multiply(pixel_size, self.t_mean_y_center_dark),
+                    'bubble_size': np.multiply(pixel_size, bubble_size_dark)}
+
+        df_dark = pd.DataFrame.from_dict(dic_dark)
+
+        dic_bright = {'list_Bright_iPSFx': np.multiply(pixel_size, self.t_mean_x_center_bright),
+                      'list_Bright_iPSFy': np.multiply(pixel_size, self.t_mean_y_center_bright),
+                      'bubble_size': np.multiply(pixel_size, bubble_size_bright)}
+
+        df_bright = pd.DataFrame.from_dict(dic_bright)
+
+        plt.figure()
+        plt.scatter('list_Dark_iPSFx', 'list_Dark_iPSFy',
+                    s='bubble_size',
+                    alpha=0.5,
+                    data=df_dark, label='Dark')
+
+        plt.scatter('list_Bright_iPSFx', 'list_Bright_iPSFy',
+                    s='bubble_size',
+                    alpha=0.5,
+                    data=df_bright, label='Bright')
+
+        plt.xlabel("X(" + unit + ")", size=20)
+        plt.ylabel("Y(" + unit + ")", size=20)
+        plt.legend()
+        plt.show()
+
     def save_hist_data(self, dirName, name, upper_limitation=1, lower_limitation=-1, Flag_GMM_fit=True, max_n_components=3):
         """
         This function save the histogram data with HDF5 format.
@@ -1052,11 +1182,3 @@ class PlotProteinHistogram(PrintColors):
 
 
 
-
-
-
-
-
-
-
-
