@@ -6,6 +6,8 @@ from PySide2.QtCore import *
 from piscat.InputOutput import write_video
 from piscat.Preproccessing.normalization import Normalization
 from piscat.Visualization.display import Display, DisplayPSFs_subplotLocalizationDisplay
+from piscat.Visualization.display_html import HTML_PSFs_subplotLocalizationDisplay
+
 from piscat.GUI.Visualization.contrast_adjustment_GUI import Contrast_adjustment_GUI
 from piscat.GUI.Visualization import slice_view
 from piscat.GUI.InputOutput import save_GUI
@@ -41,8 +43,12 @@ class ImageViewer(QtWidgets.QMainWindow, QtCore.QObject):
         self.image_series = input_image_series
         self.original_video = original_video
         self.df_PSFs = list_psf
-        self.sizeX = self.image_series.shape[1]
-        self.sizeY = self.image_series.shape[2]
+        if self.image_series.ndim == 3:
+            self.sizeX = self.image_series.shape[1]
+            self.sizeY = self.image_series.shape[2]
+        elif self.image_series.ndim == 2:
+            self.sizeX = self.image_series.shape[0]
+            self.sizeY = self.image_series.shape[1]
         self.frame_num = None
         self.current_frame = 0
         self.title = name
@@ -101,7 +107,6 @@ class ImageViewer(QtWidgets.QMainWindow, QtCore.QObject):
 
         # annotation
         self.annotation = QtWidgets.QPushButton("Live annotation")
-        # self.annotation.setAutoDefault(False)
         self.annotation.setCheckable(True)
         self.annotation.clicked.connect(self.annotationFun)
         self.annotation.setFixedWidth(130)
@@ -227,7 +232,10 @@ class ImageViewer(QtWidgets.QMainWindow, QtCore.QObject):
         self.viewer.annotation.emit()
 
     def closeEvent(self, event):
-        self.stop_video()
+        try:
+            self.stop_video()
+        except:
+            pass
         print("closed")
 
     @QtCore.Slot()
@@ -251,12 +259,12 @@ class ImageViewer(QtWidgets.QMainWindow, QtCore.QObject):
 
         if self.info_image_save.video_type == "RAW":
             if self.info_image_save.bin_type is not None:
-                type = self.original_video.astype(self.info_image_save.bin_type)
+                type = self.info_image_save.bin_type
             else:
                 type = 'original'
 
             file_name = str(self.original_video.shape[0]) + '_' + str(self.original_video.shape[1]) +'_' + \
-                        str(self.original_video.shape[2]) + '_' + str(self.original_video.dtype) + '.raw'
+                        str(self.original_video.shape[2]) + '_' + str(type) + '.raw'
             write_video.write_binary(dir_path=self.file_path, file_name=file_name, data=self.original_video, type=type)
 
         elif self.info_image_save.video_type == "MP4":
@@ -269,7 +277,7 @@ class ImageViewer(QtWidgets.QMainWindow, QtCore.QObject):
                 QtCore.QCoreApplication.processEvents()
             file_name = str(self.original_video.shape[0]) + '_' + str(self.original_video.shape[1]) + '_' + \
                         str(self.original_video.shape[2]) + '_' + str(self.original_video.dtype) + '.mp4'
-            write_video.write_MP4(dir_path=self.file_path, file_name=file_name, data=self.save_video, fps=self.fps)
+            write_video.write_MP4(dir_path=self.file_path, file_name=file_name, data=self.save_video, jump=self.frame_strides, fps=self.fps)
 
         elif self.info_image_save.video_type == "GIF":
             self.flag_update_normalization = True
@@ -279,7 +287,7 @@ class ImageViewer(QtWidgets.QMainWindow, QtCore.QObject):
             while self.flag_update_normalization:
                 QtCore.QCoreApplication.processEvents()
             file_name = str(self.original_video.shape[0]) + '_' + str(self.original_video.shape[1]) + '_' + \
-                        str(self.original_video.shape[2]) + '_' + str(self.original_video.dtype) + '.mp4'
+                        str(self.original_video.shape[2]) + '_' + str(self.original_video.dtype) + '.gif'
 
             write_video.write_GIF(dir_path=self.file_path, file_name=file_name, data=self.save_video, jump=self.frame_strides, fps=self.fps)
 
@@ -292,6 +300,8 @@ class ImageViewer(QtWidgets.QMainWindow, QtCore.QObject):
         if self.save.clicked:
             try:
                 self.info_image_save = save_GUI.SaveVideo()
+                self.info_image_save.window.show()
+
                 self.info_image_save.signal_save_Done.connect(self.call_save)
                 self.file_path = self.askdir()
 
