@@ -579,7 +579,6 @@ class JupyterSelectedPSFs_localizationDisplay():
         self.color = color
         self.flag_fit2D = flag_fit2D
         self.median_filter_flag = median_filter_flag
-        fig = plt.figure(figsize=(self.imgSizex, self.imgSizey))
 
         video_frameNum = video.shape[0]
         max_particle_frame = np.max(self.frame_number_)
@@ -595,7 +594,8 @@ class JupyterSelectedPSFs_localizationDisplay():
                                          description='Frame:'))
 
     def show_psf(self, f_num):
-
+        fig = plt.figure(figsize=(self.imgSizex, self.imgSizey))
+        ax = fig.add_axes([0, 0, 1, 1])
         if self.flag_fit2D:
             fit_params = self.fit_2D_gussian(frame_num=f_num, scale=5)
 
@@ -604,7 +604,6 @@ class JupyterSelectedPSFs_localizationDisplay():
         else:
             frame_v = self.video[int(f_num), :, :]
 
-        ax = plt.gca()
         myplot = ax.imshow(frame_v, cmap=self.color)
         divider = make_axes_locatable(ax)
         cax = divider.append_axes("right", size="5%", pad=0.05)
@@ -654,8 +653,8 @@ class JupyterSelectedPSFs_localizationDisplay():
                                    int(p_x - window_size_temp) + 1:int(p_x + window_size_temp)]
                     w_s = window_size_temp
 
-                fit_params_ = gaussian_2D_fit.fit_2D_Gaussian_varAmp(window_frame, sigma_0=start_sigma,
-                                                                     sigma_1=start_sigma,
+                fit_params_ = gaussian_2D_fit.fit_2D_Gaussian_varAmp(window_frame, sigma_x=start_sigma,
+                                                                     sigma_y=start_sigma,
                                                                      display_flag=False)
                 fit_params = fit_params_[1]
                 fit_errors = fit_params_[2]
@@ -728,7 +727,7 @@ class JupyterSubplotDisplay():
 
         max_numberFrames = np.max([vid_.shape[0] for vid_ in list_videos])
 
-        interact(self.display, frame=widgets.IntSlider(min=0, max=max_numberFrames, step=step, value=0, layout=Layout(width=IntSlider_width),
+        interact(self.display, frame=widgets.IntSlider(min=0, max=max_numberFrames-1, step=step, value=0, layout=Layout(width=IntSlider_width),
                                                        readout_format='100', continuous_update=False, description='Frame:'))
 
     def display(self, frame):
@@ -837,7 +836,7 @@ class JupyterPSFs_2_modality_subplotLocalizationDisplay():
             self.list_titles = list_titles
 
         max_numberFrames = np.max([vid_.shape[0] for vid_ in list_videos])
-        interact(self.show_psf, frame_number=widgets.IntSlider(min=0, max=max_numberFrames, step=step, value=value,
+        interact(self.show_psf, frame_number=widgets.IntSlider(min=0, max=max_numberFrames-1, step=step, value=value,
                                                                readout_format='1', continuous_update=False, layout=Layout(width=IntSlider_width),
                                                                description='Frame:'))
 
